package Daje::Controller::Kanban::KanbanPlanboard;
use Mojo::Base 'Daje::Controller::Kanban::Super::KanbanPlanboard', -base, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Controller::Kanban::KanbanPlanboard - Controller class
#
# SYNOPSIS
# ========
#
#       use Daje::Controller::Kanban::KanbanPlanboard
#
#
#
# DESCRIPTION
# ===========
#
# Daje::Controller::Kanban::KanbanPlanboard is a standard controller
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-03-15 11:55:45.
# It will not be re-generated by Daje Tools again.
# <!-- Autogenerated file 2026-03-15 11:55:45 -->

our $VERSION = '0.01';

use Data::Dumper;
use Mojo::JSON qw{ decode_json };

sub planboard_load_full_list($self) {
    $self->app->log->debug('Daje::Controller::Super::KanbanPlanboard::planboard_load_full_list ');
    $self->render_later;

    my ($companies_pkey, $users_pkey) = $self->jwt->companies_users_pkey(
        $self->req->headers->header('X-Token-Check')
    );
    my $kanban_planboard_pkey = $self->param('kanban_planboard_pkey');
    # my $setting = $self->param('setting');
    $self->kanban_planboard_helper->planboard_load($companies_pkey, $users_pkey, $kanban_planboard_pkey)->then(sub($result) {

        $self->app->log->debug('Daje::Controller::Super::KanbanPlanboard::planboard_load_full_list \n' . Dumper($result->{data}));
        #$result->{data} = decode_json($result->{data});
        $self->render(text => $result->{data}->{json_build_object});
    })->catch(sub($err) {
        $self->app->log->error('Daje::Controller::Super::KanbanPlanboard::planboard_load_full_list ' . $err);
        $self->render
    });
}
1;



#################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################

=head1 NAME


Daje::Controller::Kanban::KanbanPlanboard - Controller class



=head1 SYNOPSIS


      use Daje::Controller::Kanban::KanbanPlanboard





=head1 DESCRIPTION


Daje::Controller::Kanban::KanbanPlanboard is a standard controller



=head1 REQUIRES

L<v5.42> 

L<Mojo::Base> 


=head1 METHODS





=head1 AUTHOR


janeskil1525 E<lt>janeskil1525@gmail.com



=head1 LICENSE


Copyright (C) janeskil1525.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.



=cut

