package Daje::Plugin::Kanban::Routes;
use Mojo::Base -base, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Plugin::Kanban::Routes - Model class
#
# SYNOPSIS
# ========
#
#       use Daje::Plugin::Kanban::Routes;
#
#       my $class = Daje::Plugin::Kanban::Routes->new();
#       $r->get('/kanban/api/v1/list/:kanban_list_pkey');
#       $r->get('/kanban/api/v1/list_planboard/:kanban_planboard_fkey');

       
#       $r->get('/kanban/api/v1/planboard/:kanban_planboard_pkey');
#       $r->get('/kanban/api/v1/planboard_workflow/:kanban_workflow_fkey');

       
#       $r->get('/kanban/api/v1/planboard_companies/:kanban_companies_fkey');

       
#       $r->get('/kanban/api/v1/planboard_users/:kanban_users_fkey');

       
#       $r->get('/kanban/api/v1/cards/:kanban_cards_pkey');
#       $r->get('/kanban/api/v1/cards_priority/:kanban_priority_fkey');

       
#       $r->get('/kanban/api/v1/cards_list/:kanban_list_fkey');

       
#       $r->get('/kanban/api/v1/assignees/:kanban_assignees_pkey');
#       $r->get('/kanban/api/v1/assignees_cards/:kanban_cards_fkey');

       
#       $r->get('/kanban/api/v1/assignees_users/:kanban_users_fkey');

       
#       $r->get('/kanban/api/v1/comments/:kanban_comments_pkey');
#       $r->get('/kanban/api/v1/comments_cards/:kanban_cards_fkey');

       
#       $r->get('/kanban/api/v1/priority/:kanban_priority_pkey');
#       $r->get('/kanban/api/v1/attachments/:kanban_attachments_pkey');
#       $r->get('/kanban/api/v1/attachments_cards/:kanban_cards_fkey');

       
#       $r->get('/kanban/api/v1/tasks/:kanban_tasks_pkey');
#       $r->get('/kanban/api/v1/tasks_cards/:kanban_cards_fkey');

       
#       $r->get('/kanban/api/v1/task/:kanban_task_pkey');
#       $r->get('/kanban/api/v1/task_tasks/:kanban_tasks_fkey');

       #
#
# DESCRIPTION
# ===========
#
# Daje::Plugin::Kanban::Routes is the standard routes
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-03-28 17:58:35.
# It will be generated by Daje Tools again.
# <!-- Autogenerated file 2026-03-28 17:58:35 -->

our $VERSION = '0.01';

sub routes($self, $app, $config) {
    my $r = $app->auth;

    $r->get('v1/list_list_all/')->to('KanbanListList#load_all_kanban_list');
    $r->get('v1/list_planboard_list/:kanban_planboard_fkey')->to('KanbanList#load_list_kanban_planboard_fkey');
    $r->get('v1/planboard_list_all/')->to('KanbanPlanboardList#load_all_kanban_planboard');
    $r->get('v1/planboard_workflow_list/:kanban_workflow_fkey')->to('KanbanPlanboard#load_list_kanban_workflow_fkey');
    $r->get('v1/planboard_companies_list/:companies_companies_fkey')->to('KanbanPlanboard#load_list_companies_companies_fkey');
    $r->get('v1/planboard_users_list/:users_users_fkey')->to('KanbanPlanboard#load_list_users_users_fkey');
    $r->get('v1/cards_list_all/')->to('KanbanCardsList#load_all_kanban_cards');
    $r->get('v1/cards_priority_list/:kanban_priority_fkey')->to('KanbanCards#load_list_kanban_priority_fkey');
    $r->get('v1/cards_list_list/:kanban_list_fkey')->to('KanbanCards#load_list_kanban_list_fkey');
    $r->get('v1/assignees_list_all/')->to('KanbanAssigneesList#load_all_kanban_assignees');
    $r->get('v1/assignees_cards_list/:kanban_cards_fkey')->to('KanbanAssignees#load_list_kanban_cards_fkey');
    $r->get('v1/assignees_users_list/:users_users_fkey')->to('KanbanAssignees#load_list_users_users_fkey');
    $r->get('v1/comments_list_all/')->to('KanbanCommentsList#load_all_kanban_comments');
    $r->get('v1/comments_cards_list/:kanban_cards_fkey')->to('KanbanComments#load_list_kanban_cards_fkey');
    $r->get('v1/priority_list_all/')->to('KanbanPriorityList#load_all_kanban_priority');
    $r->get('v1/attachments_list_all/')->to('KanbanAttachmentsList#load_all_kanban_attachments');
    $r->get('v1/attachments_cards_list/:kanban_cards_fkey')->to('KanbanAttachments#load_list_kanban_cards_fkey');
    $r->get('v1/tasks_list_all/')->to('KanbanTasksList#load_all_kanban_tasks');
    $r->get('v1/tasks_cards_list/:kanban_cards_fkey')->to('KanbanTasks#load_list_kanban_cards_fkey');
    $r->get('v1/task_list_all/')->to('KanbanTaskList#load_all_kanban_task');
    $r->get('v1/task_tasks_list/:kanban_tasks_fkey')->to('KanbanTask#load_list_kanban_tasks_fkey');

    $r->get('v1/list_planboard/:kanban_planboard_fkey')->to('KanbanList#load_kanban_planboard_fkey');    $r->get('v1/list/:kanban_list_pkey')->to('KanbanList#load_kanban_list_pkey');
    $r->get('v1/planboard_workflow/:kanban_workflow_fkey')->to('KanbanPlanboard#load_kanban_workflow_fkey');
    $r->get('v1/planboard_companies/:kanban_companies_fkey')->to('KanbanPlanboard#load_kanban_companies_fkey');
    $r->get('v1/planboard_users/:kanban_users_fkey')->to('KanbanPlanboard#load_kanban_users_fkey');    $r->get('v1/planboard/:kanban_planboard_pkey')->to('KanbanPlanboard#load_kanban_planboard_pkey');
    $r->get('v1/cards_priority/:kanban_priority_fkey')->to('KanbanCards#load_kanban_priority_fkey');
    $r->get('v1/cards_list/:kanban_list_fkey')->to('KanbanCards#load_kanban_list_fkey');    $r->get('v1/cards/:kanban_cards_pkey')->to('KanbanCards#load_kanban_cards_pkey');
    $r->get('v1/assignees_cards/:kanban_cards_fkey')->to('KanbanAssignees#load_kanban_cards_fkey');
    $r->get('v1/assignees_users/:kanban_users_fkey')->to('KanbanAssignees#load_kanban_users_fkey');    $r->get('v1/assignees/:kanban_assignees_pkey')->to('KanbanAssignees#load_kanban_assignees_pkey');
    $r->get('v1/comments_cards/:kanban_cards_fkey')->to('KanbanComments#load_kanban_cards_fkey');    $r->get('v1/comments/:kanban_comments_pkey')->to('KanbanComments#load_kanban_comments_pkey');    $r->get('v1/priority/:kanban_priority_pkey')->to('KanbanPriority#load_kanban_priority_pkey');
    $r->get('v1/attachments_cards/:kanban_cards_fkey')->to('KanbanAttachments#load_kanban_cards_fkey');    $r->get('v1/attachments/:kanban_attachments_pkey')->to('KanbanAttachments#load_kanban_attachments_pkey');
    $r->get('v1/tasks_cards/:kanban_cards_fkey')->to('KanbanTasks#load_kanban_cards_fkey');    $r->get('v1/tasks/:kanban_tasks_pkey')->to('KanbanTasks#load_kanban_tasks_pkey');
    $r->get('v1/task_tasks/:kanban_tasks_fkey')->to('KanbanTask#load_kanban_tasks_fkey');    $r->get('v1/task/:kanban_task_pkey')->to('KanbanTask#load_kanban_task_pkey');
}

