package Daje::Plugin::Kanban::Languages;
use Mojo::Base -base, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Plugin::Kanban::Languages - Model class
#
# SYNOPSIS
# ========
#
#
#
#
# DESCRIPTION
# ===========
#
# Daje::Plugin::Kanban::Languages is the standard routes
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-03-28 17:58:35.
# It will be generated by Daje Tools again.
# <!-- Autogenerated file 2026-03-28 17:58:35 -->

use Daje::Helper::Languages::InsertKeys;

has 'db';

sub language($self) {

    try {
        my $tx = $self->db->begin;
        my @keys;
        push @keys, {
                plugin => 'kanban',
                key => 'list',
                field => 'table',
                type => 'Label',
                translation => 'List',
                comment => 'Kanban column',
            };
          push @keys,  {
                plugin => 'kanban',
                key => 'list',
                field => 'planboard',
                type => 'Label',
                translation => 'Planboard',
                comment => 'Planboard'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'list',
                field => 'planboard',
                type => 'Tool tips',
                translation => 'Planboard',
                comment => 'Planboard'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'list',
                field => 'title',
                type => 'Label',
                translation => 'Title',
                comment => 'Title'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'list',
                field => 'title',
                type => 'Tool tips',
                translation => 'Title',
                comment => 'Title'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'list',
                field => 'active',
                type => 'Label',
                translation => 'Active',
                comment => 'Active'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'list',
                field => 'active',
                type => 'Tool tips',
                translation => 'Active',
                comment => 'Active'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'list',
                field => 'listid',
                type => 'Label',
                translation => 'ListId',
                comment => 'ListId'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'list',
                field => 'listid',
                type => 'Tool tips',
                translation => 'ListId',
                comment => 'ListId'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'list',
                field => 'sort_order',
                type => 'Label',
                translation => 'Sort Order',
                comment => 'Sort Order'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'list',
                field => 'sort_order',
                type => 'Tool tips',
                translation => 'Sort Order',
                comment => 'Sort Order'
            };
         
        push @keys, {
                plugin => 'kanban',
                key => 'planboard',
                field => 'table',
                type => 'Label',
                translation => 'Planboard',
                comment => 'Planboard (data)',
            };
          push @keys,  {
                plugin => 'kanban',
                key => 'planboard',
                field => 'workflow',
                type => 'Label',
                translation => 'Workflow',
                comment => 'Workflow'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'planboard',
                field => 'workflow',
                type => 'Tool tips',
                translation => 'Workflow',
                comment => 'Workflow'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'planboard',
                field => 'comment',
                type => 'Label',
                translation => 'Comment',
                comment => 'Comment'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'planboard',
                field => 'comment',
                type => 'Tool tips',
                translation => 'Comment',
                comment => 'Comment'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'planboard',
                field => 'name',
                type => 'Label',
                translation => 'Name',
                comment => 'Planboard name'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'planboard',
                field => 'name',
                type => 'Tool tips',
                translation => 'Planboard name',
                comment => 'Planboard name'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'planboard',
                field => 'companies',
                type => 'Label',
                translation => 'Companies',
                comment => 'Companies'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'planboard',
                field => 'companies',
                type => 'Tool tips',
                translation => 'Companies',
                comment => 'Companies'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'planboard',
                field => 'users',
                type => 'Label',
                translation => 'User',
                comment => 'User'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'planboard',
                field => 'users',
                type => 'Tool tips',
                translation => 'User',
                comment => 'User'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'planboard',
                field => 'active',
                type => 'Label',
                translation => 'Active',
                comment => 'Active'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'planboard',
                field => 'active',
                type => 'Tool tips',
                translation => 'Active',
                comment => 'Active'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'planboard',
                field => 'duedate',
                type => 'Label',
                translation => 'Due date',
                comment => 'Due date'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'planboard',
                field => 'duedate',
                type => 'Tool tips',
                translation => 'Due date',
                comment => 'Due date'
            };
         
        push @keys, {
                plugin => 'kanban',
                key => 'cards',
                field => 'table',
                type => 'Label',
                translation => 'Planboard Cards',
                comment => 'Planboard cards',
            };
          push @keys,  {
                plugin => 'kanban',
                key => 'cards',
                field => 'title',
                type => 'Label',
                translation => 'Title',
                comment => 'Title'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'cards',
                field => 'title',
                type => 'Tool tips',
                translation => 'Title',
                comment => 'Title'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'cards',
                field => 'description',
                type => 'Label',
                translation => 'Description',
                comment => 'Description'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'cards',
                field => 'description',
                type => 'Tool tips',
                translation => 'Description',
                comment => 'Description'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'cards',
                field => 'startdate',
                type => 'Label',
                translation => 'Start date',
                comment => 'Start date'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'cards',
                field => 'startdate',
                type => 'Tool tips',
                translation => 'Start date',
                comment => 'Start date'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'cards',
                field => 'duedate',
                type => 'Label',
                translation => 'Due date',
                comment => 'Due date'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'cards',
                field => 'duedate',
                type => 'Tool tips',
                translation => 'Due date',
                comment => 'Due date'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'cards',
                field => 'completed',
                type => 'Label',
                translation => 'Completed',
                comment => 'Completed'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'cards',
                field => 'completed',
                type => 'Tool tips',
                translation => 'Completed',
                comment => 'Completed'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'cards',
                field => 'progress',
                type => 'Label',
                translation => 'Progress',
                comment => 'Progress'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'cards',
                field => 'progress',
                type => 'Tool tips',
                translation => 'Progress',
                comment => 'Progress'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'cards',
                field => 'priority',
                type => 'Label',
                translation => 'Priority',
                comment => 'Priority'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'cards',
                field => 'priority',
                type => 'Tool tips',
                translation => 'Priority',
                comment => 'Priority'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'cards',
                field => 'list',
                type => 'Label',
                translation => 'List',
                comment => 'List'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'cards',
                field => 'list',
                type => 'Tool tips',
                translation => 'List',
                comment => 'List'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'cards',
                field => 'id',
                type => 'Label',
                translation => 'Card id',
                comment => 'Card id'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'cards',
                field => 'id',
                type => 'Tool tips',
                translation => 'Card id',
                comment => 'Card id'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'cards',
                field => 'sort_order',
                type => 'Label',
                translation => 'Sort Order',
                comment => 'Sort Order'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'cards',
                field => 'sort_order',
                type => 'Tool tips',
                translation => 'Sort Order',
                comment => 'Sort Order'
            };
         
        push @keys, {
                plugin => 'kanban',
                key => 'assignees',
                field => 'table',
                type => 'Label',
                translation => 'Assignees',
                comment => 'Assignees',
            };
          push @keys,  {
                plugin => 'kanban',
                key => 'assignees',
                field => 'cards',
                type => 'Label',
                translation => 'Cards',
                comment => 'Cards'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'assignees',
                field => 'cards',
                type => 'Tool tips',
                translation => 'Cards',
                comment => 'Cards'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'assignees',
                field => 'users',
                type => 'Label',
                translation => 'Users',
                comment => 'Users'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'assignees',
                field => 'users',
                type => 'Tool tips',
                translation => 'Users',
                comment => 'Users'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'assignees',
                field => 'comment',
                type => 'Label',
                translation => 'Comment',
                comment => 'Comment'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'assignees',
                field => 'comment',
                type => 'Tool tips',
                translation => 'Comment',
                comment => 'Comment'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'assignees',
                field => 'name',
                type => 'Label',
                translation => 'Name',
                comment => 'Name'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'assignees',
                field => 'name',
                type => 'Tool tips',
                translation => 'Name',
                comment => 'Name'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'assignees',
                field => 'image',
                type => 'Label',
                translation => 'Image',
                comment => 'Image'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'assignees',
                field => 'image',
                type => 'Tool tips',
                translation => 'Image',
                comment => 'Image'
            };
         
        push @keys, {
                plugin => 'kanban',
                key => 'comments',
                field => 'table',
                type => 'Label',
                translation => 'Comments',
                comment => 'Comments',
            };
          push @keys,  {
                plugin => 'kanban',
                key => 'comments',
                field => 'cards',
                type => 'Label',
                translation => 'Cards',
                comment => 'Cards'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'comments',
                field => 'cards',
                type => 'Tool tips',
                translation => 'Cards',
                comment => 'Cards'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'comments',
                field => 'id',
                type => 'Label',
                translation => 'id',
                comment => 'id'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'comments',
                field => 'id',
                type => 'Tool tips',
                translation => 'id',
                comment => 'id'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'comments',
                field => 'text',
                type => 'Label',
                translation => 'Text',
                comment => 'Text'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'comments',
                field => 'text',
                type => 'Tool tips',
                translation => 'Text',
                comment => 'Text'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'comments',
                field => 'name',
                type => 'Label',
                translation => 'User commenting',
                comment => 'User commenting'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'comments',
                field => 'name',
                type => 'Tool tips',
                translation => 'User commenting',
                comment => 'User commenting'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'comments',
                field => 'image',
                type => 'Label',
                translation => 'Avatar',
                comment => 'Avatar'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'comments',
                field => 'image',
                type => 'Tool tips',
                translation => 'Avatar',
                comment => 'Avatar'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'comments',
                field => 'comment_date',
                type => 'Label',
                translation => 'Comment Date',
                comment => 'Comment Date'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'comments',
                field => 'comment_date',
                type => 'Tool tips',
                translation => 'Comment Date',
                comment => 'Comment Date'
            };
         
        push @keys, {
                plugin => 'kanban',
                key => 'priority',
                field => 'table',
                type => 'Label',
                translation => 'Priority',
                comment => 'Priority',
            };
          push @keys,  {
                plugin => 'kanban',
                key => 'priority',
                field => 'color',
                type => 'Label',
                translation => 'Color',
                comment => 'Color'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'priority',
                field => 'color',
                type => 'Tool tips',
                translation => 'Color',
                comment => 'Color'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'priority',
                field => 'title',
                type => 'Label',
                translation => 'Title',
                comment => 'Title'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'priority',
                field => 'title',
                type => 'Tool tips',
                translation => 'Title',
                comment => 'Title'
            };
         
        push @keys, {
                plugin => 'kanban',
                key => 'attachments',
                field => 'table',
                type => 'Label',
                translation => 'Attachments',
                comment => 'Attachments',
            };
          push @keys,  {
                plugin => 'kanban',
                key => 'attachments',
                field => 'cards',
                type => 'Label',
                translation => 'Cards',
                comment => 'Cards'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'attachments',
                field => 'cards',
                type => 'Tool tips',
                translation => 'Cards',
                comment => 'Cards'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'attachments',
                field => 'filename',
                type => 'Label',
                translation => 'Filename',
                comment => 'Filename'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'attachments',
                field => 'filename',
                type => 'Tool tips',
                translation => 'Filename',
                comment => 'Filename'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'attachments',
                field => 'comment',
                type => 'Label',
                translation => 'Comment',
                comment => 'Comment'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'attachments',
                field => 'comment',
                type => 'Tool tips',
                translation => 'Comment',
                comment => 'Comment'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'attachments',
                field => 'document',
                type => 'Label',
                translation => 'Document',
                comment => 'Document'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'attachments',
                field => 'document',
                type => 'Tool tips',
                translation => 'Document',
                comment => 'Document'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'attachments',
                field => 'type',
                type => 'Label',
                translation => 'Type',
                comment => 'Type'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'attachments',
                field => 'type',
                type => 'Tool tips',
                translation => 'Type',
                comment => 'Type'
            };
         
        push @keys, {
                plugin => 'kanban',
                key => 'tasks',
                field => 'table',
                type => 'Label',
                translation => 'Tasks',
                comment => 'Tasks',
            };
          push @keys,  {
                plugin => 'kanban',
                key => 'tasks',
                field => 'cards',
                type => 'Label',
                translation => 'Cards',
                comment => 'Cards'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'tasks',
                field => 'cards',
                type => 'Tool tips',
                translation => 'Cards',
                comment => 'Cards'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'tasks',
                field => 'completed',
                type => 'Label',
                translation => 'Completed',
                comment => 'Completed'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'tasks',
                field => 'completed',
                type => 'Tool tips',
                translation => 'Completed',
                comment => 'Completed'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'tasks',
                field => 'estimated',
                type => 'Label',
                translation => 'Estimated time (h)',
                comment => 'Estimated time (h)'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'tasks',
                field => 'estimated',
                type => 'Tool tips',
                translation => 'Estimated time (h)',
                comment => 'Estimated time (h)'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'tasks',
                field => 'booked',
                type => 'Label',
                translation => 'Booked time (h)',
                comment => 'Booked time (h)'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'tasks',
                field => 'booked',
                type => 'Tool tips',
                translation => 'Booked time (h)',
                comment => 'Booked time (h)'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'tasks',
                field => 'id',
                type => 'Label',
                translation => 'id',
                comment => 'id'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'tasks',
                field => 'id',
                type => 'Tool tips',
                translation => 'id',
                comment => 'id'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'tasks',
                field => 'title',
                type => 'Label',
                translation => 'title',
                comment => 'title'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'tasks',
                field => 'title',
                type => 'Tool tips',
                translation => 'title',
                comment => 'title'
            };
         
        push @keys, {
                plugin => 'kanban',
                key => 'task',
                field => 'table',
                type => 'Label',
                translation => 'Task',
                comment => 'Task',
            };
          push @keys,  {
                plugin => 'kanban',
                key => 'task',
                field => 'text',
                type => 'Label',
                translation => 'Text',
                comment => 'Text'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'task',
                field => 'text',
                type => 'Tool tips',
                translation => 'Text',
                comment => 'Text'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'task',
                field => 'completed',
                type => 'Label',
                translation => 'completed',
                comment => 'completed'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'task',
                field => 'completed',
                type => 'Tool tips',
                translation => 'completed',
                comment => 'completed'
            };
         
          push @keys,  {
                plugin => 'kanban',
                key => 'task',
                field => 'tasks',
                type => 'Label',
                translation => 'Tasks',
                comment => 'Tasks'
            };
           push @keys, {
                plugin => 'kanban',
                key => 'task',
                field => 'tasks',
                type => 'Tool tips',
                translation => 'Tasks',
                comment => 'Tasks'
            };
         

        Daje::Helper::Languages::InsertKeys->new(
            db => $self->db
        )->process(
             \@keys
        );
        $tx->commit();
    } catch($e) {
        say $e;
    }
}

1;


