package Daje::Plugin::Kanban::Helpers;
use Mojo::Base -base, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Plugin::Kanban::Helpers - Model class
#
# SYNOPSIS
# ========
#
#       use Daje::Plugin::Kanban::Helpers;
#
#       my $class = Daje::Plugin::Kanban::Helpers->new();
#       $app->helper(
#           v_kanban_list => sub {
#               state  $v_kanban_list = Daje::Database::Model::vKanbanList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_kanban_planboard => sub {
#               state  $v_kanban_planboard = Daje::Database::Model::vKanbanPlanboard->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_kanban_cards => sub {
#               state  $v_kanban_cards = Daje::Database::Model::vKanbanCards->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_kanban_assignees => sub {
#               state  $v_kanban_assignees = Daje::Database::Model::vKanbanAssignees->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_kanban_comments => sub {
#               state  $v_kanban_comments = Daje::Database::Model::vKanbanComments->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_kanban_priority => sub {
#               state  $v_kanban_priority = Daje::Database::Model::vKanbanPriority->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_kanban_attachments => sub {
#               state  $v_kanban_attachments = Daje::Database::Model::vKanbanAttachments->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_kanban_tasks => sub {
#               state  $v_kanban_tasks = Daje::Database::Model::vKanbanTasks->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_kanban_task => sub {
#               state  $v_kanban_task = Daje::Database::Model::vKanbanTask->new(db => shift->pg->db)
#        });#
#       $app->helper(
#           v_kanban_list_list => sub {
#               state  $v_kanban_list_list = Daje::Database::Model::vKanbanListList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_kanban_planboard_list => sub {
#               state  $v_kanban_planboard_list = Daje::Database::Model::vKanbanPlanboardList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_kanban_cards_list => sub {
#               state  $v_kanban_cards_list = Daje::Database::Model::vKanbanCardsList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_kanban_assignees_list => sub {
#               state  $v_kanban_assignees_list = Daje::Database::Model::vKanbanAssigneesList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_kanban_comments_list => sub {
#               state  $v_kanban_comments_list = Daje::Database::Model::vKanbanCommentsList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_kanban_priority_list => sub {
#               state  $v_kanban_priority_list = Daje::Database::Model::vKanbanPriorityList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_kanban_attachments_list => sub {
#               state  $v_kanban_attachments_list = Daje::Database::Model::vKanbanAttachmentsList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_kanban_tasks_list => sub {
#               state  $v_kanban_tasks_list = Daje::Database::Model::vKanbanTasksList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_kanban_task_list => sub {
#               state  $v_kanban_task_list = Daje::Database::Model::vKanbanTaskList->new(db => shift->pg->db)
#        });#
# DESCRIPTION
# ===========
#
# Daje::Plugin::Kanban::Helpers is the standard routes
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-03-28 17:58:35.
# It will be re-generated by Daje Tools again.
# <!-- Autogenerated file 2026-03-28 17:58:35 -->

use Daje::Database::View::vKanbanList;
use Daje::Database::View::vKanbanPlanboard;
use Daje::Database::View::vKanbanCards;
use Daje::Database::View::vKanbanAssignees;
use Daje::Database::View::vKanbanComments;
use Daje::Database::View::vKanbanPriority;
use Daje::Database::View::vKanbanAttachments;
use Daje::Database::View::vKanbanTasks;
use Daje::Database::View::vKanbanTask;# Lists
use Daje::Database::View::vKanbanListList;
use Daje::Database::View::vKanbanPlanboardList;
use Daje::Database::View::vKanbanCardsList;
use Daje::Database::View::vKanbanAssigneesList;
use Daje::Database::View::vKanbanCommentsList;
use Daje::Database::View::vKanbanPriorityList;
use Daje::Database::View::vKanbanAttachmentsList;
use Daje::Database::View::vKanbanTasksList;
use Daje::Database::View::vKanbanTaskList;

our $VERSION = '0.01';

sub helpers($self, $app, $config) {

    $app->helper(
        v_kanban_list => sub {
            state  $v_kanban_list = Daje::Database::View::vKanbanList->new(db => shift->pg->db)
        });
    $app->helper(
        v_kanban_planboard => sub {
            state  $v_kanban_planboard = Daje::Database::View::vKanbanPlanboard->new(db => shift->pg->db)
        });
    $app->helper(
        v_kanban_cards => sub {
            state  $v_kanban_cards = Daje::Database::View::vKanbanCards->new(db => shift->pg->db)
        });
    $app->helper(
        v_kanban_assignees => sub {
            state  $v_kanban_assignees = Daje::Database::View::vKanbanAssignees->new(db => shift->pg->db)
        });
    $app->helper(
        v_kanban_comments => sub {
            state  $v_kanban_comments = Daje::Database::View::vKanbanComments->new(db => shift->pg->db)
        });
    $app->helper(
        v_kanban_priority => sub {
            state  $v_kanban_priority = Daje::Database::View::vKanbanPriority->new(db => shift->pg->db)
        });
    $app->helper(
        v_kanban_attachments => sub {
            state  $v_kanban_attachments = Daje::Database::View::vKanbanAttachments->new(db => shift->pg->db)
        });
    $app->helper(
        v_kanban_tasks => sub {
            state  $v_kanban_tasks = Daje::Database::View::vKanbanTasks->new(db => shift->pg->db)
        });
    $app->helper(
        v_kanban_task => sub {
            state  $v_kanban_task = Daje::Database::View::vKanbanTask->new(db => shift->pg->db)
        });    # Lists
    $app->helper(
        v_kanban_list_list => sub {
            state  $v_kanban_list_list = Daje::Database::View::vKanbanListList->new(db => shift->pg->db)
        });
    $app->helper(
        v_kanban_planboard_list => sub {
            state  $v_kanban_planboard_list = Daje::Database::View::vKanbanPlanboardList->new(db => shift->pg->db)
        });
    $app->helper(
        v_kanban_cards_list => sub {
            state  $v_kanban_cards_list = Daje::Database::View::vKanbanCardsList->new(db => shift->pg->db)
        });
    $app->helper(
        v_kanban_assignees_list => sub {
            state  $v_kanban_assignees_list = Daje::Database::View::vKanbanAssigneesList->new(db => shift->pg->db)
        });
    $app->helper(
        v_kanban_comments_list => sub {
            state  $v_kanban_comments_list = Daje::Database::View::vKanbanCommentsList->new(db => shift->pg->db)
        });
    $app->helper(
        v_kanban_priority_list => sub {
            state  $v_kanban_priority_list = Daje::Database::View::vKanbanPriorityList->new(db => shift->pg->db)
        });
    $app->helper(
        v_kanban_attachments_list => sub {
            state  $v_kanban_attachments_list = Daje::Database::View::vKanbanAttachmentsList->new(db => shift->pg->db)
        });
    $app->helper(
        v_kanban_tasks_list => sub {
            state  $v_kanban_tasks_list = Daje::Database::View::vKanbanTasksList->new(db => shift->pg->db)
        });
    $app->helper(
        v_kanban_task_list => sub {
            state  $v_kanban_task_list = Daje::Database::View::vKanbanTaskList->new(db => shift->pg->db)
        });}

1;



